import { Resolver, Query, Args, Mutation } from '@nestjs/graphql';
import { Citation } from './citation';
import { Post } from '../post/post';

@Resolver(of => Citation)
export class CitationsResolver {

    constructor() {}

    @Query()
    citations() {
        return Citation.getAllCitations();
    }

    @Query()
    citation(@Args('id') id: string) {
        return Citation.getCitation(id);
    }

    @Query()
    isNeutral(@Args('citationId'!) id: string) {
        const citation = Citation.getCitation(id);
        if (!citation) return null;
        return citation.isNeutral();
    }

    @Query()
    isPositive(@Args('citationId'!) id: string) {
        const citation = Citation.getCitation(id);
        if (!citation) return null;
        return citation.isPositive();
    }

    @Query()
    isNegative(@Args('citationId'!) id: string) {
        const citation = Citation.getCitation(id);
        if (!citation) return null;
        return citation.isNegative();
    }

    @Query()
    adjacentPost(
        @Args('citationId'!) citationId: string,
        @Args('postId'!) postId: string
    ) {
        const citation = Citation.getCitation(citationId);
        const post = Post.getPost(postId);
        if (!citation || !post) return null;
        return citation.getAdjacent(post);
    }

    @Mutation()
    createCitation(
        @Args('citationId') id: string,
        @Args('sourcePostId'!) sourcePostId: string,
        @Args('citedPostId'!) citedPostId: string,
        @Args('impact'!) impact: number
    ) {
        const sourcePost = Post.getPost(sourcePostId);
        const citedPost = Post.getPost(citedPostId);
        if (!sourcePost || !citedPost) return null;
        return new Citation(id, sourcePost, citedPost, impact);
    }
}
