import { Args, Mutation, Query, Resolver } from "@nestjs/graphql";
import { Member } from "./member";

@Resolver(of => Member)
export class MemberResolver {
    
    constructor() {}

    @Query()
    members() {
        return Member.getAllMembers();
    }

    @Query()
    member(@Args('id') id: string) {
        return Member.getMember(id);
    }

    @Mutation()
    createMember(@Args('id') id?: string) {
        return new Member(id);
    }

    @Mutation()
    postRep(
        @Args('memberId'!) memberId: string,
        @Args('postId'!) postId: string,
        @Args('amount'!) amount: number,
    ) {
        const member = Member.getMember(memberId);
        if (!member) return null; 
        return member.postReputation(postId, amount);
    }
  
    @Mutation()
    citationRep(
        @Args('memberId'!) memberId: string,
        @Args('postId'!) postId: string,
        @Args('citationId'!) citationId: string,
        @Args('amount'!) amount: number,
    ) {
        const member = Member.getMember(memberId);
        if (!member) return null;
        return member.citationReputation(postId, citationId, amount); 
    }


}