import { Resolver, Query, Args, Mutation } from "@nestjs/graphql";
import { Post } from "./post";
import { Member } from "../member/member";
import { Citation } from "../citation/citation";

@Resolver(of => Post)
export class PostResolver {

    constructor() {}

    @Query()
    posts() {
        return Post.getAllPosts();
    }

    @Query()
    post(@Args('id') id: string) {
        return Post.getPost(id);
    }

    @Query()
    authorWeight(
        @Args('postId'!) postId: string, 
        @Args('authorId'!) authorId: string
    ) {
        const post = Post.getPost(postId);
        const author = Member.getMember(authorId);
        if (!post || !author) return null;
        return post.getWeight(author);
    }

    @Query() 
    citationWeight(
        @Args('postId'!) postId: string, 
        @Args('citationId'!) citationId: string
    ) {
        const post = Post.getPost(postId);
        const citation = Citation.getCitation(citationId);
        if (!post || !citation) return null;
        return post.getWeight(citation);
    }


    @Mutation()
    createPost(
        @Args('id') id: string,
        @Args('title'!) title: string,
        @Args('content'!) content: string,
        @Args('authorId'!) authorId: string,
    ) {
        const author = Member.getMember(authorId);
        if (!author) return null;
        return new Post(id, title, content, author);
    }
  
    @Mutation()
    setAuthor(
        @Args('postId'!) postId: string,
        @Args('authorId'!) authorId: string,
        @Args('weight'!) weight: number,
    ) {
        const post = Post.getPost(postId);
        const author = Member.getMember(authorId);
        if (!post || !author) return false;
        post.setAuthor(author, weight);
        return true;
    }
  
    @Mutation()
    removeAuthor(
        @Args('postId'!) postId: string,
        @Args('citationId'!) authorId: string,
    ) {
        const post = Post.getPost(postId);
        const author = Member.getMember(authorId);
        if (!post || !author) return false;
        post.removeAuthor(author);
        return true;
    }

    @Mutation()
    setCitation(
        @Args('postId'!) postId: string,
        @Args('citationId'!) citationId: string,
        @Args('weight'!) weight: number,
    ) {
        const post = Post.getPost(postId);
        const citation = Citation.getCitation(citationId);
        if (!post || !citation) return false;
        post.setCitation(citation, weight);
        return true;
    }

    @Mutation()
    removeCitation(
        @Args('postId'!) postId: string,
        @Args('citationId'!) citationId: string,
    ) {
        const post = Post.getPost(postId);
        const citation = Citation.getCitation(citationId);
        if (!post || !citation) return false;
        post.removeCitation(citation);
        return true;
    }

}